@@ -1,11 +1,12 @@
 #!/bin/bash
 
+aembit_raw_prerouting_chain_name=aembit_raw_prerouting_chain
 aembit_raw_output_chain_name=aembit_raw_output_chain
 aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
 aembit_filter_input_chain_name=aembit_filter_input_chain
 
-custom_chains=("raw,OUTPUT,$aembit_raw_output_chain_name" "nat,OUTPUT,$aembit_nat_output_chain_name" "nat,PREROUTING,$aembit_nat_prerouting_chain_name" "filter,INPUT,$aembit_filter_input_chain_name")
+custom_chains=("raw,PREROUTING,$aembit_raw_prerouting_chain_name" "raw,OUTPUT,$aembit_raw_output_chain_name" "nat,OUTPUT,$aembit_nat_output_chain_name" "nat,PREROUTING,$aembit_nat_prerouting_chain_name" "filter,INPUT,$aembit_filter_input_chain_name")
 
 for custom_chain in "${custom_chains[@]}"; do
     # Split to table, buildit chain and custom chain name
